"use strict";
/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.KafkaResourcesFactory = exports.KafkaResources = void 0;
const sillyname_1 = __importDefault(require("sillyname"));
const kafkaNodeConsumer_1 = require("./kafkaNodeConsumer");
class KafkaResources {
    constructor(lambdaFactory, consumer, config) {
        this.lambdaFactory = lambdaFactory;
        this.consumer = consumer;
        this.config = config;
    }
    async dispose() {
        const consumerClosedP = this.consumer.close();
        await Promise.all([consumerClosedP]);
    }
}
exports.KafkaResources = KafkaResources;
class KafkaResourcesFactory {
    constructor(name, lambdaModule) {
        this.name = name;
        this.lambdaModule = lambdaModule;
    }
    async create(config) {
        // eslint-disable-next-line @typescript-eslint/no-require-imports, @typescript-eslint/no-var-requires
        const plugin = require(this.lambdaModule);
        const lambdaFactory = await plugin.create(config);
        // Inbound Kafka configuration
        const kafkaEndpoint = config.get("kafka:lib:endpoint");
        const zookeeperEndpoint = config.get("zookeeper:endpoint");
        const numberOfPartitions = config.get("kafka:lib:numberOfPartitions");
        const replicationFactor = config.get("kafka:lib:replicationFactor");
        // Receive topic and group - for now we will assume an entry in config mapping
        // to the given name. Later though the lambda config will likely be split from the stream config
        const streamConfig = config.get(`lambdas:${this.name}`);
        const groupId = streamConfig.group;
        const receiveTopic = streamConfig.topic;
        const clientId = (0, sillyname_1.default)().toLowerCase().split(" ").join("-");
        const consumer = new kafkaNodeConsumer_1.KafkaNodeConsumer({ kafkaHost: kafkaEndpoint }, clientId, groupId, receiveTopic, zookeeperEndpoint, numberOfPartitions, replicationFactor);
        return new KafkaResources(lambdaFactory, consumer, config);
    }
}
exports.KafkaResourcesFactory = KafkaResourcesFactory;
//# sourceMappingURL=resourcesFactory.js.map